@@ -10,11 +10,13 @@ from fastel.authorizers import (
     StaticSecretAuth,
 )
 from fastel.cart.exceptions import CartException, cart_exception_handler
-from fastel.exceptions import APIException
+from fastel.collections import set_collections
+from fastel.exceptions import APIException, api_exception_handler
 
-__version__ = "1.2.6"
+__version__ = "1.8.5"
 __all__ = [
     "APIException",
+    "api_exception_handler",
     "ClientIdAuth",
     "ClientSecretAuth",
     "Credential",
@@ -24,4 +26,5 @@ __all__ = [
     "StaticJWTAuth",
     "cart_exception_handler",
     "CartException",
+    "set_collections",
 ]
